@@ -531,6 +531,7 @@ void ServerConfig::Fill()
 	HideBans = security->getBool("hidebans");
 	HideWhoisServer = security->getString("hidewhois");
 	HideKillsServer = security->getString("hidekills");
+	HideULineKills = security->getBool("hideulinekills");
 	RestrictBannedUsers = security->getBool("restrictbannedusers", true);
 	GenericOper = security->getBool("genericoper");
 	NoUserDns = ConfValue("performance")->getBool("nouserdns");
@@ -728,7 +729,7 @@ void ServerConfig::Apply(ServerConfig* old, const std::string &useruid)
 
 	// write once here, to try it out and make sure its ok
 	if (valid)
-		ServerInstance->WritePID(this->PID);
+		ServerInstance->WritePID(this->PID, !old);
 
 	if (old && valid)
 	{
